@@ -1,14 +1,15 @@
-use super::{
-  argparse::{Action, Engine, Options},
-  fs_pipe::{slurp, spit},
-  input::Payload,
-  types::Fail,
-  udiff::{apply_patches, patches, pure_diffs, udiff},
+use {
+  super::{
+    argparse::{Action, Engine, Options},
+    fs_pipe::{slurp, spit},
+    input::Payload,
+    types::Fail,
+    udiff::{apply_patches, patches, pure_diffs, udiff},
+  },
+  ansi_term::Colour,
+  std::{ffi::OsString, path::PathBuf, sync::Arc},
+  tokio::task::spawn_blocking,
 };
-use ansi_term::Colour;
-use pathdiff::diff_paths;
-use std::{path::PathBuf, sync::Arc};
-use tokio::task::spawn_blocking;
 
 impl Engine {
   fn replace(&self, before: &str) -> String {
@@ -20,23 +21,23 @@ impl Engine {
 }
 
 impl Payload {
-  fn path(&self) -> &PathBuf {
+  const fn path(&self) -> &PathBuf {
     match self {
-      Payload::Entire(path) => path,
-      Payload::Piecewise(path, _) => path,
+      Payload::Entire(path) | Payload::Piecewise(path, _) => path,
     }
   }
 }
 
-pub async fn displace(opts: &Arc<Options>, payload: Payload) -> Result<String, Fail> {
+pub async fn displace(opts: &Arc<Options>, payload: Payload) -> Result<OsString, Fail> {
   let path = payload.path().clone();
-  let rel_path = opts
+  let name = opts
     .cwd
     .as_ref()
-    .and_then(|cwd| diff_paths(&path, cwd))
-    .unwrap_or_else(|| path.clone());
+    .and_then(|cwd| path.strip_prefix(cwd).ok())
+    .unwrap_or_else(|| path.as_ref())
+    .as_os_str()
+    .to_owned();
 
-  let name = format!("{}", rel_path.display());
   let slurped = slurp(&path).await?;
   let before = Arc::new(slurped.content);
 
@@ -46,7 +47,7 @@ pub async fn displace(opts: &Arc<Options>, payload: Payload) -> Result<String, F
   let after = spawn_blocking(move || o.engine.replace(&b)).await?;
 
   if *before == after {
-    Ok(String::new())
+    Ok(OsString::new())
   } else {
     let print = match (&opts.action, payload) {
       (Action::Preview, Payload::Entire(_)) => {
@@ -57,7 +58,9 @@ pub async fn displace(opts: &Arc<Options>, payload: Payload) -> Result<String, F
       }
       (Action::Commit, Payload::Entire(_)) => {
         spit(&path, &slurped.meta, &after).await?;
-        format!("{name}\n")
+        let mut out = OsString::from(name);
+        out.push("\n");
+        out
       }
       (Action::Commit, Payload::Piecewise(_, ranges)) => {
         let after = spawn_blocking(move || {
@@ -67,16 +70,19 @@ pub async fn displace(opts: &Arc<Options>, payload: Payload) -> Result<String, F
         .await?;
 
         spit(&path, &slurped.meta, &after).await?;
-        format!("{name}\n")
+        let mut out = OsString::from(name);
+        out.push("\n");
+        out
       }
       (Action::FzfPreview(_, _), _) => {
         spawn_blocking(move || {
           let ranges = pure_diffs(o2.unified, &before, &after);
-          let mut fzf_lines = String::new();
+          let mut fzf_lines = OsString::new();
           for range in ranges {
             let repr = Colour::Red.paint(format!("{range}"));
-            let line = format!("{name}\n\n\n\n{repr}\0");
-            fzf_lines.push_str(&line);
+            fzf_lines.push(&name);
+            let line = format!("\n\n\n\n{repr}\0");
+            fzf_lines.push(&line);
           }
           fzf_lines
         })
