@@ -1,31 +1,28 @@
-use super::{
-  argparse::{Arguments, Mode},
-  types::{Abort, Fail},
-  udiff::DiffRange,
+use {
+  super::{
+    argparse::{Arguments, Mode},
+    types::{Abort, Fail},
+    udiff::DiffRange,
+  },
+  async_channel::{bounded, Receiver},
+  futures::{
+    future::{select, Either},
+    pin_mut,
+  },
+  regex::Regex,
+  std::{
+    collections::{HashMap, HashSet},
+    ffi::OsString,
+    io::ErrorKind,
+    path::{Path, PathBuf},
+    sync::Arc,
+  },
+  tokio::{
+    fs::{canonicalize, File},
+    io::{stdin, AsyncBufReadExt, BufReader},
+    task::{spawn, JoinHandle},
+  },
 };
-use async_channel::{bounded, Receiver};
-use futures::{
-  future::{select, Either},
-  pin_mut,
-};
-use regex::Regex;
-use std::{
-  collections::{HashMap, HashSet},
-  ffi::OsString,
-  io::ErrorKind,
-  path::{Path, PathBuf},
-  sync::Arc,
-};
-use tokio::{
-  fs::{canonicalize, File},
-  io::{stdin, AsyncBufReadExt, BufReader},
-  task::{spawn, JoinHandle},
-};
-
-#[cfg(target_family = "unix")]
-use std::os::unix::ffi::OsStringExt;
-#[cfg(target_family = "windows")]
-use std::{convert::TryInto, os::windows::ffi::OsStringExt};
 
 #[derive(Debug)]
 pub enum Payload {
@@ -35,11 +32,11 @@ pub enum Payload {
 
 struct DiffLine(PathBuf, DiffRange);
 
-fn p_line(line: String) -> Result<DiffLine, Fail> {
+fn p_line(line: &str) -> Result<DiffLine, Fail> {
   let f = Fail::ArgumentError(String::new());
   let preg = "\n\n\n\n@@ -(\\d+),(\\d+) \\+(\\d+),(\\d+) @@$";
   let re = Regex::new(preg).map_err(Fail::RegexError)?;
-  let captures = re.captures(&line).ok_or_else(|| f.clone())?;
+  let captures = re.captures(line).ok_or_else(|| f.clone())?;
 
   let before_start = captures
     .get(1)
@@ -70,14 +67,14 @@ fn p_line(line: String) -> Result<DiffLine, Fail> {
     before: (before_start - 1, before_inc),
     after: (after_start - 1, after_inc),
   };
-  let path = PathBuf::from(String::from(re.replace(&line, "")));
+  let path = PathBuf::from(String::from(re.replace(line, "")));
   Ok(DiffLine(path, range))
 }
 
-async fn read_patches(path: &Path) -> Result<HashMap<PathBuf, HashSet<DiffRange>>, Fail> {
-  let fd = File::open(path)
+async fn read_patches(path_file: &Path) -> Result<HashMap<PathBuf, HashSet<DiffRange>>, Fail> {
+  let fd = File::open(path_file)
     .await
-    .map_err(|e| Fail::IO(path.to_owned(), e.kind()))?;
+    .map_err(|e| Fail::IO(path_file.to_owned(), e.kind()))?;
   let mut reader = BufReader::new(fd);
   let mut acc = HashMap::<PathBuf, HashSet<DiffRange>>::new();
 
@@ -86,26 +83,22 @@ async fn read_patches(path: &Path) -> Result<HashMap<PathBuf, HashSet<DiffRange>
     let n = reader
       .read_until(b'\0', &mut buf)
       .await
-      .map_err(|e| Fail::IO(path.to_owned(), e.kind()))?;
+      .map_err(|e| Fail::IO(path_file.to_owned(), e.kind()))?;
 
-    match n {
-      0 => break,
-      _ => {
-        buf.pop();
-        let line =
-          String::from_utf8(buf).map_err(|_| Fail::IO(path.to_owned(), ErrorKind::InvalidData))?;
-        let patch = p_line(line)?;
-        match acc.get_mut(&patch.0) {
-          Some(ranges) => {
-            ranges.insert(patch.1);
-          }
-          None => {
-            let mut ranges = HashSet::new();
-            ranges.insert(patch.1);
-            acc.insert(patch.0, ranges);
-          }
-        }
-      }
+    if n == 0 {
+      break;
+    }
+
+    buf.pop();
+    let line =
+      String::from_utf8(buf).map_err(|_| Fail::IO(path_file.to_owned(), ErrorKind::InvalidData))?;
+    let patch = p_line(&line)?;
+    if let Some(ranges) = acc.get_mut(&patch.0) {
+      ranges.insert(patch.1);
+    } else {
+      let mut ranges = HashSet::new();
+      ranges.insert(patch.1);
+      acc.insert(patch.0, ranges);
     }
   }
 
@@ -137,10 +130,12 @@ fn stream_patch(abort: &Arc<Abort>, patch: &Path) -> (JoinHandle<()>, Receiver<P
 fn u8_pathbuf(v8: Vec<u8>) -> PathBuf {
   #[cfg(target_family = "unix")]
   {
+    use std::os::unix::ffi::OsStringExt;
     PathBuf::from(OsString::from_vec(v8))
   }
   #[cfg(target_family = "windows")]
   {
+    use std::{convert::TryInto, os::windows::ffi::OsStringExt};
     let mut buf = Vec::new();
     for chunk in v8.chunks_exact(2) {
       let c: [u8; 2] = chunk.try_into().expect("exact chunks");
@@ -175,14 +170,13 @@ fn stream_stdin(abort: &Arc<Abort>, use_nul: bool) -> (JoinHandle<()>, Receiver<
         pin_mut!(f1);
         pin_mut!(f2);
         match select(f1, f2).await {
-          Either::Left(_) => break,
+          Either::Left(_) | Either::Right((Ok(0), _)) => break,
           Either::Right((Err(err), _)) => {
             abort
               .send(Fail::IO(PathBuf::from("/dev/stdin"), err.kind()))
               .await;
             break;
           }
-          Either::Right((Ok(0), _)) => break,
           Either::Right((Ok(_), _)) => {
             buf.pop();
             let path = u8_pathbuf(buf);
@@ -208,14 +202,13 @@ fn stream_stdin(abort: &Arc<Abort>, use_nul: bool) -> (JoinHandle<()>, Receiver<
   (handle, rx)
 }
 
-pub fn stream_input(
+pub fn stream_in(
   abort: &Arc<Abort>,
   mode: &Mode,
   args: &Arguments,
 ) -> (JoinHandle<()>, Receiver<Payload>) {
   match mode {
     Mode::Initial => stream_stdin(abort, args.read0),
-    Mode::Preview(path) => stream_patch(abort, path),
-    Mode::Patch(path) => stream_patch(abort, path),
+    Mode::Preview(path) | Mode::Patch(path) => stream_patch(abort, path),
   }
 }
