@@ -1,18 +1,20 @@
-use super::types::{Abort, Fail};
-use futures::{
-  future::{select, try_join, Either},
-  pin_mut,
-};
-use std::{collections::HashMap, path::PathBuf, process::Stdio, sync::Arc};
-use tokio::{
-  io::{AsyncWrite, AsyncWriteExt, BufWriter},
-  process::Command,
-  sync::mpsc::Receiver,
-  task::{spawn, JoinHandle},
+use {
+  super::types::{Abort, Fail},
+  futures::{
+    future::{select, try_join, Either},
+    pin_mut,
+  },
+  std::{collections::HashMap, ffi::OsString, path::PathBuf, process::Stdio, sync::Arc},
+  tokio::{
+    io::{AsyncWrite, AsyncWriteExt, BufWriter},
+    process::Command,
+    sync::mpsc::Receiver,
+    task::{spawn, JoinHandle},
+  },
 };
 
 #[derive(Clone, Debug)]
-pub struct SubprocessCommand {
+pub struct SubprocCommand {
   pub prog: PathBuf,
   pub args: Vec<String>,
   pub env: HashMap<String, String>,
@@ -21,8 +23,8 @@ pub struct SubprocessCommand {
 pub async fn stream_into(
   abort: &Arc<Abort>,
   path: PathBuf,
-  writer: &mut BufWriter<impl AsyncWrite + Unpin>,
-  mut stream: Receiver<String>,
+  writer: &mut BufWriter<impl AsyncWrite + Send + Unpin>,
+  mut stream: Receiver<OsString>,
 ) {
   loop {
     let f1 = abort.notified();
@@ -30,9 +32,17 @@ pub async fn stream_into(
     pin_mut!(f1);
     pin_mut!(f2);
     match select(f1, f2).await {
-      Either::Left(_) => break,
       Either::Right((Some(print), _)) => {
-        if let Err(err) = writer.write(print.as_bytes()).await {
+        #[cfg(target_family = "unix")]
+        let bytes = {
+          use std::os::unix::ffi::OsStrExt;
+          print.as_bytes()
+        };
+        #[cfg(target_family = "windows")]
+        let tmp = print.to_string_lossy();
+        #[cfg(target_family = "windows")]
+        let bytes = tmp.as_bytes();
+        if let Err(err) = writer.write_all(bytes).await {
           abort.send(Fail::IO(path, err.kind())).await;
           break;
         }
@@ -42,10 +52,10 @@ pub async fn stream_into(
   }
 }
 
-pub fn stream_subprocess(
+pub fn stream_subproc(
   abort: &Arc<Abort>,
-  cmd: SubprocessCommand,
-  stream: Receiver<String>,
+  cmd: SubprocCommand,
+  stream: Receiver<OsString>,
 ) -> JoinHandle<()> {
   let abort = abort.clone();
 
@@ -80,7 +90,7 @@ pub fn stream_subprocess(
         });
 
         if let Err(err) = try_join(handle_child, handle_in).await {
-          abort.send(err.into()).await
+          abort.send(err.into()).await;
         }
       }
     }
