@@ -1,15 +1,17 @@
-use regex::Error as RegexError;
-use std::{
-  clone::Clone,
-  error::Error,
-  fmt::{self, Display, Formatter},
-  io::ErrorKind,
-  path::PathBuf,
-  sync::Arc,
-};
-use tokio::{
-  sync::{Mutex, Notify},
-  task::JoinError,
+use {
+  regex::Error as RegexError,
+  std::{
+    clone::Clone,
+    error::Error,
+    fmt::{self, Display, Formatter},
+    io::ErrorKind,
+    path::PathBuf,
+    sync::Arc,
+  },
+  tokio::{
+    sync::{Mutex, Notify},
+    task::JoinError,
+  },
 };
 
 #[derive(Clone, Debug)]
@@ -33,16 +35,16 @@ impl Display for Fail {
 impl From<JoinError> for Fail {
   fn from(e: JoinError) -> Self {
     if e.is_cancelled() {
-      Fail::Interrupt
+      Self::Interrupt
     } else {
-      Fail::Join
+      Self::Join
     }
   }
 }
 
 impl From<RegexError> for Fail {
   fn from(e: RegexError) -> Self {
-    Fail::RegexError(e)
+    Self::RegexError(e)
   }
 }
 
@@ -53,7 +55,7 @@ pub struct Abort {
 
 impl Abort {
   pub fn new() -> Arc<Self> {
-    Arc::new(Abort {
+    Arc::new(Self {
       errors: Mutex::new(Vec::new()),
       rx: Notify::new(),
     })
@@ -66,14 +68,14 @@ impl Abort {
   pub async fn send(&self, fail: Fail) {
     let mut errors = self.errors.lock().await;
     errors.push(fail);
-    self.rx.notify_waiters()
+    self.rx.notify_waiters();
   }
 
   pub async fn notified(&self) {
     let errors = self.errors.lock().await;
     if errors.len() > 0 {
     } else {
-      self.rx.notified().await
+      self.rx.notified().await;
     }
   }
 }
